Module oqtant.tests.unit.test_oqtant_client
===========================================

Functions
---------


`test_generate_oqtant_job(settings, job_fixtures)`
:


`test_generate_oqtant_job_validation_error(settings)`
:


`test_get_headers(settings)`
:


`test_get_job(mock_get, settings, mock_response, mock_external_id, job_fixtures)`
:


`test_get_job_invalid_data(mock_get, settings, mock_response, mock_external_id)`
:


`test_get_job_limits(settings)`
:


`test_get_job_limits_unauthorized(settings)`
:


`test_get_job_not_authorized(mock_get, settings)`
:


`test_get_job_not_found(mock_get, settings)`
:


`test_instantiate_api()`
:


`test_load_from_file_invalid(settings)`
:


`test_load_from_id(mock_get, settings, mock_response, job_fixtures)`
:


`test_load_from_id_invalid(mock_get, settings)`
:


`test_run_job_list(settings, mock_job_create, mock_external_id, job_fixtures)`
:


`test_run_job_list_one_invalid(mock_post, settings, mock_response, mock_job_create, job_fixtures)`
:


`test_see_active_jobs(mock_get, settings, mock_response, job_fixtures)`
:


`test_submit_job(mock_post, settings, mock_response, mock_job_create, mock_external_id, job_fixtures)`
:


`test_submit_job_unauthorized(mock_post, settings, job_fixtures)`
:


`test_track_jobs_with_failed_job(mock_get, settings, mock_response, mock_external_id, job_fixtures)`
:


`test_track_jobs_with_filename(mock_get, settings, mock_response, mock_external_id, job_fixtures)`
:


`test_track_jobs_with_unequal_filename_list(mock_get, settings, mock_response, mock_external_id, job_fixtures)`
:


`test_track_jobs_without_filename(mock_get, settings, mock_response, mock_external_id, job_fixtures)`
:
